@@ -76,6 +76,9 @@ struct utsname
 #ifndef WIFSIGNALED
 # define WIFSIGNALED(s) ((s) & 0)  /* Can't use for BSD */
 #endif
+#ifndef WTERMSIG
+#define WTERMSIG(s) ((s) & 0)
+#endif
 
 
 #include <errno.h>
@@ -149,12 +152,12 @@ extern int errno;
 #ifdef HAVE_UTIME_H
 # include <utime.h>      /* use utime not utimes for portability */
 #elif TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
+#  include <sys/time.h>
+#  include <time.h>
 #elif HAVE_SYS_TIME_H
-# include <sys/time.h>
+#  include <sys/time.h>
 #elif ! defined(AOS)
-# include <time.h>
+#  include <time.h>
 #endif
 
 #include <pwd.h>
