@@ -241,7 +241,7 @@ while (!feof(fp))
    variable[0]='\0';
    value[0]='\0';
 
-   if (strlen(buffer)== 0)
+   if (strlen(buffer)== 0 || buffer[0] == '#')
       {
       continue;
       }
@@ -465,6 +465,7 @@ if (VTIMEZONE[0] == '\0')
    FatalError("Program does not define a timezone");
    }
 
+#ifndef AOS
 #ifndef SUN4
 
 tzset();
@@ -497,7 +498,8 @@ else
    Verbose("\nThe timezone is %s\n\n",VTIMEZONE);
    }
 
-#endif
+#endif /* SUN4 */
+#endif /* AOS  */
 }
 
 /*******************************************************************/
@@ -579,8 +581,27 @@ for (i = 0; CLASSATTRIBUTES[i][0] != '\0'; i++)
       }
    }
 
+if ((sp = malloc(strlen(VSYSNAME.nodename)+1)) == NULL)
+   {
+   FatalError("malloc failure in initialize()");
+   }
+
+strcpy(sp,VSYSNAME.nodename);
+
+for (sp2=sp; *sp2 != '\0'; sp2++)  /* Truncate fully qualified name */
+   {
+   if (*sp2 == '.')
+      {
+      *sp2 = '\0';
+
+      Verbose("cfengine: INFO! Truncating fully qualified hostname %s to %s\n",VSYSNAME.nodename,sp);
+      break;
+      }
+   }
+
+AddClassToHeap(sp);                 /* Unqualified host name comes first */
+VDEFAULTBINSERVER.name = sp;
 
-AddClassToHeap(VSYSNAME.nodename);   /* Make sure hostname has priority */
 VSYSTEMHARDCLASS = (enum classes) i;
 
 
@@ -667,26 +688,6 @@ else
    strcpy(VARCH,VSYSNAME.sysname);
    }
 
-if ((sp = malloc(strlen(VSYSNAME.nodename)+1)) == NULL)
-   {
-   FatalError("malloc failure in initialize()");
-   }
-
-strcpy(sp,VSYSNAME.nodename);
-
-for (sp2=sp; *sp2 != '\0'; sp2++)  /* Truncate fully qualified name */
-   {
-   if (*sp2 == '.')
-      {
-      *sp2 = '\0';
-
-      Verbose("cfengine: INFO! Truncating fully qualified hostname %s to %s\n",VSYSNAME.nodename,sp);
-
-      break;
-      }
-   }
-
-VDEFAULTBINSERVER.name = sp;
 
 if (! found)
    {
@@ -1287,10 +1288,19 @@ GetMountInfo ()  /* This is, in fact, the most portable way to read the mount in
   struct Item *mp;
   char buf1[bufsize],buf2[bufsize],buf3[bufsize];
   char host[maxvarsize], mounton[bufsize];
+  int i;
 
 Banner("cfengine: Building list of currently mounted filesystems");
 
-sscanf(VMOUNTCOMM[VSYSTEMHARDCLASS],"%s",buf1); /* extract mount path */
+#ifndef BSD43
+sscanf(VMOUNTCOMM[VSYSTEMHARDCLASS],"%s",buf1);
+#else
+for (i=0; VMOUNTCOMM[VSYSTEMHARDCLASS][i] != ' '; i++)
+   {
+   buf1[i] =  VMOUNTCOMM[VSYSTEMHARDCLASS][i];
+   }
+buf1[i] = '\0';
+#endif
 
 if ((pp = popen(buf1,"r")) == NULL)
    {
@@ -3768,7 +3778,8 @@ for (i=0; OPTIONS[i].name != NULL; i++)
    printf("--%-20s    (-%c)\n",OPTIONS[i].name,(char)OPTIONS[i].val);
    }
 
-printf("\n");
+printf("\nBug reports to bug-cfengine@gnu.ai.mit.edu\n");
+printf("Info & fixes at http://www.iu.hioslo.no/~mark/cfengine.html\n");
 }
 
 /*******************************************************************/
