@@ -37,9 +37,10 @@
 
 /*********************************************************************/
 
+                      /* See also "enum classes" in cf.defs.h        */
 char *CLASSTEXT[] =   /* If you change here change enum classes too! */
    {
-   "",                                              /* see cf.defs.h */
+   "",
    "<soft>",
    "faculty",
    "site",
@@ -74,6 +75,11 @@ char *CLASSTEXT[] =   /* If you change here change enum classes too! */
    "sun3",
    "irix",
    "freebsd",
+   "solarisx86",
+   "bsd4_3",
+   "newsos",
+   "netbsd",
+   "aos",
    "unused1",
    "unused2",
    "unused3",
@@ -108,17 +114,22 @@ char *CLASSATTRIBUTES[clssattr][attr] = /* Used to match the softclass */
    "-","-","-",
    "-","-","-",
    "-","-","-",   
-   "sunos","sun4?","4*",       /* sun 4  */
+   "sunos","*","4*",           /* sun 4  */
    "ultrix","risc","4*",       /* ultrix */
    "hp-ux","9000*","?.1?.*",   /* hpux10 */
    "hp-ux","9000*","*",        /* hpux */
-   "aix","*","2",              /* aix */
+   "aix","*","?",              /* aix */
    "linux","*","*",            /* linux */
    "sunos","sun4?","5*",       /* solaris */
    "osf1","alpha","*",         /* osf1 */
    "sunos","sun3","4*",        /* sun3 */
    "irix","ip*","5*",          /* irix */
    "freebsd","i?86","*",       /* freebsd */
+   "sunos","i86pc","5*",       /* solarisx86 */
+   "bsd","*","*",              /* bsd 4.3 */
+   "newsos","*","*",           /* newsos4 */
+   "netbsd","*","*",           /* NetBSD */
+   "aos","*","*",              /* AOS */
    "unused1","blah","blah",
    "unused2","blah","blah",
    "unused3","blah","blah",
@@ -153,17 +164,22 @@ char *VPSCOMM[clssattr] =
    "",
    "",
    "",   
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
-   "/bin/ps",
+   "/bin/ps",       /* sun 4  */
+   "/bin/ps",       /* ultrix */
+   "/bin/ps",       /* hpux10 */
+   "/bin/ps",       /* hpux */
+   "/bin/ps",       /* aix */
+   "/bin/ps",       /* linux */
+   "/bin/ps",       /* solaris */
+   "/bin/ps",       /* osf1 */
+   "/bin/ps",       /* sun3 */
+   "/bin/ps",       /* irix */
+   "/bin/ps",       /* freebsd */
+   "/bin/ps",       /* solarisx86 */
+   "/bin/ps",       /* bsd 4.3 */
+   "/bin/ps",       /* newos4 */
+   "/bin/ps",       /* netbsd */
+   "/bin/ps",       /* AOS */
    "/bin/ps",
    "/bin/ps",
    "/bin/ps",
@@ -200,8 +216,8 @@ char *VPSOPTS[clssattr] =
    "",
    "-ax",    /* sun4 */
    "-ax",    /* ultrix */
-   "-ef",     /* hp10 */
-   "-ef",    /* houx */
+   "-ef",    /* hp10 */
+   "-ef",    /* hpux */
    "-ef",    /* aix */
    "-ax",    /* linux */
    "-ef",    /* solaris */
@@ -209,6 +225,11 @@ char *VPSOPTS[clssattr] =
    "-ax",    /* sun3 */
    "-ef",    /* irix */
    "-ax",    /* freebsd */
+   "-ef",    /* solarisx86 */
+   "-ax",    /* bsd 4.3 */
+   "-ax",    /* newsos4 */
+   "-ax",    /* netbsd */
+   "-ax",    /* AOS */
    "-",
    "-",
    "-",
@@ -243,17 +264,22 @@ char *VMOUNTCOMM[clssattr] =
    "",
    "",
    "",
-   "/etc/mount -va 2<&1",
-   "/etc/mount -va 2<&1",
-   "/sbin/mount -va 2<&1",
-   "/etc/mount -va 2<&1",
-   "/etc/mount -t nfs 2<&1",
-   "/sbin/mount -va 2<&1",        /* not sure about these */
-   "/usr/sbin/mount -a 2>&1",
-   "/usr/sbin/mount -va 2<&1",
-   "/etc/mount -va 2<&1",
-   "/sbin/mount -va 2<&1",
-   "/sbin/mount -vau 2<&1",
+   "/etc/mount -va 2<&1",      /* sun4 */
+   "/etc/mount -va 2<&1",      /* ultrix */
+   "/sbin/mount -va 2<&1",     /* hpux10 */
+   "/etc/mount -va 2<&1",      /* hpux */
+   "/etc/mount -t nfs 2<&1",   /* aix */
+   "/sbin/mount -va 2<&1",     /* linux */
+   "/usr/sbin/mount -a 2>&1",  /* solaris */
+   "/usr/sbin/mount -va 2<&1", /* osf1 */
+   "/etc/mount -va 2<&1",      /* sun3 */
+   "/sbin/mount -va 2<&1",     /* irix */
+   "/sbin/mount -va 2<&1" ,    /* freebsd */
+   "/usr/sbin/mount -a 2>&1",  /* solarisx86 */
+   "/etc/mount -a 2>&1",       /* bsd 4.3 */
+   "/etc/mount -a 2>&1",       /* newsos4 */
+   "/sbin/mount -a 2>&1",      /* netbsd */
+   "/etc/mount -a 2>&1",       /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -288,17 +314,22 @@ char *VUNMOUNTCOMM[clssattr] =
    "",
    "",
    "",
-   "/etc/umount",
-   "/etc/umount",
-   "/sbin/umount",
-   "/etc/umount",
-   "/etc/umount",
-   "/sbin/umount",        /* not sure about these */
-   "/etc/umount",
-   "/usr/sbin/umount",
-   "/etc/umount",
-   "/sbin/umount",
-   "/sbin/umount",
+   "/etc/umount",      /* sun4 */
+   "/etc/umount",      /* ultrix */
+   "/sbin/umount",     /* hpux10 */
+   "/etc/umount",      /* hpux */
+   "/etc/umount",      /* aix */
+   "/sbin/umount",     /* linux */
+   "/etc/umount",      /* solaris */
+   "/usr/sbin/umount", /* osf1 */
+   "/etc/umount",      /* sun3 */
+   "/sbin/umount",     /* irix */
+   "/sbin/umount",     /* freebsd */
+   "/etc/umount",      /* solarisx86 */
+   "/etc/umount",      /* bsd4.3 */
+   "/etc/umount",      /* newsos4 */
+   "/sbin/umount",     /* netbsd */
+   "/etc/umount",      /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -335,17 +366,22 @@ char *VMOUNTOPTS[clssattr] =
    "",
    "",
    "",
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "defaults",        /* not sure about these */
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "bg,hard,intr",
-   "bg,intr",
+   "bg,hard,intr",    /* sun4 */
+   "bg,hard,intr",    /* ultrix */
+   "bg,hard,intr",    /* hpux10 */
+   "bg,hard,intr",    /* hpux */
+   "bg,hard,intr",    /* aix */
+   "defaults",        /* linux */
+   "bg,hard,intr",    /* solaris */
+   "bg,hard,intr",    /* osf1 */
+   "bg,hard,intr",    /* sun3 */
+   "bg,hard,intr",    /* irix */
+   "bg,intr",         /* freebsd */
+   "bg,hard,intr",    /* solarisx86 */
+   "bg,hard,intr",    /* bsd4.3 */
+   "bg,hard,intr",    /* newsos4 */
+   "-i,-b,noauto",    /* netbsd */
+   "bg,hard,intr",    /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -380,17 +416,22 @@ char *VIFDEV[clssattr] =
    "-",
    "-",
    "-",
-   "le0",
-   "ln0",
-   "lan0",
-   "lan0",
-   "en0",
-   "eth0",    
-   "le0",
-   "ln0",
-   "le0",
-   "ec0",
-   "ep0",
+   "le0",    /* sun4 */
+   "ln0",    /* ultrix */
+   "lan0",   /* hpux10 */
+   "lan0",   /* hpux */
+   "en0",    /* aix */
+   "eth0",   /* linux */ 
+   "le0",    /* solaris */
+   "ln0",    /* osf1 */
+   "le0",    /* sun3 */
+   "ec0",    /* irix */
+   "ep0",    /* freebsd */
+   "dnet0",  /* solarisx86 */
+   "le0",    /* bsd4.3 */
+   "en0",    /* newsos4 */
+   "le0",    /* netbsd */
+   "un0",    /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -426,17 +467,22 @@ char *VRESOLVCONF[clssattr] =
    "-",
    "-",
    "-",
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",    
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",
-   "/etc/resolv.conf",
-   "/usr/etc/resolv.conf",
-   "/etc/resolv.conf",
+   "/etc/resolv.conf",     /* sun4 */
+   "/etc/resolv.conf",     /* ultrix */
+   "/etc/resolv.conf",     /* hpux10 */
+   "/etc/resolv.conf",     /* hpux */
+   "/etc/resolv.conf",     /* aix */
+   "/etc/resolv.conf",     /* linux */   
+   "/etc/resolv.conf",     /* solaris */
+   "/etc/resolv.conf",     /* osf1 */
+   "/etc/resolv.conf",     /* sun3 */
+   "/usr/etc/resolv.conf", /* irix */
+   "/etc/resolv.conf",     /* freebsd */
+   "/etc/resolv.conf",     /* solarisx86 */
+   "/etc/resolv.conf",     /* bsd4.3 */
+   "/etc/resolv.conf",     /* newsos4 */
+   "/etc/resolv.conf",     /* netbsd */
+   "/etc/resolv.conf",     /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -473,17 +519,22 @@ char *VFSTAB[clssattr] =
    "-",
    "-",
    "-",
-   "/etc/fstab",
-   "/etc/fstab",
-   "/etc/fstab",
-   "/etc/checklist",
-   "/etc/filesystems",
-   "/etc/fstab",    
-   "/etc/vfstab",
-   "/etc/fstab",
-   "/etc/fstab",
-   "/etc/fstab",
-   "/etc/fstab",
+   "/etc/fstab",       /* sun4 */
+   "/etc/fstab",       /* ultrix */
+   "/etc/fstab",       /* hpux10 */
+   "/etc/checklist",   /* hpux */
+   "/etc/filesystems", /* aix */
+   "/etc/fstab",       /* linux */
+   "/etc/vfstab",      /* solaris */
+   "/etc/fstab",       /* osf1 */
+   "/etc/fstab",       /* sun3 */
+   "/etc/fstab",       /* irix */
+   "/etc/fstab",       /* freebsd */
+   "/etc/vfstab",      /* solarisx86 */
+   "/etc/fstab",       /* bsd4.3 */
+   "/etc/fstab",       /* newsos4 */
+   "/etc/fstab",       /* netbsd */
+   "/etc/fstab",       /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -518,17 +569,22 @@ char *VMAILDIR[clssattr] =
    "-",
    "-",
    "-",
-   "/var/spool/mail",
-   "/usr/spool/mail",
-   "/var/mail",
-   "/usr/mail",
-   "/var/spool/mail",
-   "/var/spool/mail",    
-   "/var/mail",
-   "/usr/spool/mail",
-   "/var/spool/mail",
-   "/usr/mail",
-   "/var/mail",
+   "/var/spool/mail",    /* sun4 */
+   "/usr/spool/mail",    /* ultrix */
+   "/var/mail",          /* hpux10 */
+   "/usr/mail",          /* hpux */
+   "/var/spool/mail",    /* aix */
+   "/var/spool/mail",    /* linux */  
+   "/var/mail",          /* solaris */
+   "/usr/spool/mail",    /* osf1 */
+   "/var/spool/mail",    /* sun3 */
+   "/usr/mail",          /* irix */
+   "/var/mail",          /* freebsd */
+   "/var/mail",          /* solarisx86 */
+   "/usr/spool/mail",    /* bsd4.3 */
+   "/usr/spool/mail",    /* newsos4 */
+   "/var/mail",          /* netbsd */
+   "/usr/spool/mail",    /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
@@ -563,17 +619,22 @@ char *VNETSTAT[clssattr] =
    "-",
    "-",
    "-",
-   "/usr/ucb/netstat -rn",
-   "/usr/ucb/netstat -rn",
-   "/usr/bin/netstat -rn",
-   "/usr/bin/netstat -rn",
-   "/usr/bin/netstat -rn",
-   "/bin/netstat -rn",    
-   "/usr/ucb/netstat -rn",
-   "/usr/sbin/netstat -rn",
-   "/usr/ucb/netstat -rn",
-   "/usr/etc/netstat -rn",
-   "/usr/bin/netstat -rn",
+   "/usr/ucb/netstat -rn",   /* sun4 */
+   "/usr/ucb/netstat -rn",   /* ultrix */
+   "/usr/bin/netstat -rn",   /* hpux10 */
+   "/usr/bin/netstat -rn",   /* hpux */
+   "/usr/bin/netstat -rn",   /* aix */
+   "/bin/netstat -rn",       /* linux */
+   "/usr/ucb/netstat -rn",   /* solaris */
+   "/usr/sbin/netstat -rn",  /* osf1 */
+   "/usr/ucb/netstat -rn",   /* sun3 */
+   "/usr/etc/netstat -rn",   /* irix */
+   "/usr/bin/netstat -rn",   /* freebsd */
+   "/bin/netstat -rn",       /* solarisx86 */
+   "/usr/ucb/netstat -rn",   /* bsd4.3 */
+   "/usr/ucb/netstat -rn",   /* newsos4 */
+   "/usr/bin/netstat -rn",   /* netbsd */
+   "/usr/ucb/netstat -rn",   /* AOS */
    "unused-blah",
    "unused-blah",
    "unused-blah",
