@@ -623,6 +623,10 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                   InsertItemAfter (&filestart,CURRENTLINEPTR,ep->data);
                   break;
 
+      case InsertFile:
+	          InsertFileAfter(&filestart,CURRENTLINEPTR,ep->data);
+		  break;
+
       case IncrementPointer:
                if (! IncrementEditPointer(ep->data,filestart))     /* edittools */
                   {
@@ -700,8 +704,20 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                   EditVerbose("          Aborting file editing of %s.\n",filename);
                   goto abort;
                   }
-               break;	       
+               break;
 
+      case UnCommentLinesContaining:
+               while (UnCommentItemContaining(&filestart,ep->data,COMMENTSTART,COMMENTEND))
+                  {
+                  }
+               break;
+
+      case UnCommentLinesMatching:
+               while (UnCommentItemMatching(&filestart,ep->data,COMMENTSTART,COMMENTEND))
+                  {
+                  }
+               break;
+	       
       case SetScript:
                currenteditscript = ep->data;
                break;
@@ -740,6 +756,8 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                EditVerbose("Edit: Emptying entire file\n");
                DeleteItemList(filestart);
 	       filestart = NULL;
+	       CURRENTLINEPTR = NULL;
+	       CURRENTLINENUMBER=0;
                NUMBEROFEDITS++;
                break;
 
@@ -756,6 +774,12 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                break;
 
       case BeginGroupIfNoMatch:
+	       if (CURRENTLINEPTR == NULL || CURRENTLINEPTR->name == NULL )
+		  {
+		  EditVerbose("Edit: (Begin Group - no match for %s - file empty)\n",ep->data);
+		  break;
+		  }
+	       
                if (LineMatches(CURRENTLINEPTR->name,ep->data))
                   {
                   EditVerbose("Edit: (Begin Group - skipping)\n",ep->data);
@@ -786,7 +810,7 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                break;
 
      case BeginGroupIfNoSuchLine:
-               if (! IsItemIn(filestart,ep->data))
+               if (IsItemIn(filestart,ep->data))
                   {
                   EditVerbose("Edit: (Begin Group - skipping)\n");
                   while(ep->code != EndGroup)
@@ -796,7 +820,7 @@ for (ep = ptr->actions; ep != NULL; ep=ep->next)
                   }
                else
                   {
-                  EditVerbose("Edit: (Begin Group - no such line %s)\n",ep->data);
+                  EditVerbose("Edit: (Begin Group - no line %s)\n",ep->data);
                   }
                break;
 
@@ -866,6 +890,20 @@ if (n == 0)
    return false;
    }
 
+if (CURRENTLINEPTR == NULL)  /* is prev undefined, set to line 1 */
+   {
+   if (liststart == NULL)
+      {
+      EditVerbose("Edit: cannot increment line pointer in empty file\n");
+      return true;
+      }
+   else
+      {
+      CURRENTLINEPTR=liststart;
+      CURRENTLINENUMBER=1;
+      }
+   }
+
 
 if (n < 0)
    {
