@@ -93,7 +93,7 @@ if ((dirh = opendir(from)) == NULL)
 
 if (ip->next != bug_check)
    {
-   printf("cfengine: SVR4 opendir() bug: opendir wrecked the heap memory!!");
+   printf("cfengine: solaris opendir() bug: opendir wrecked the heap memory!!");
    printf("          in copy to %s, using workaround...\n",from);
    ip->next = bug_check;
    }
@@ -180,7 +180,7 @@ struct Image *ip;
   struct passwd *pw;
   struct stat statbuf;
   int request_uid = ip->uid->uid;  /* save if -1 */
-  
+
 if (!MountPathDefined())
    {
    printf("cfengine: mountpattern is undefined\n");
@@ -473,6 +473,7 @@ if (lstat(destfile,&deststatbuf) == -1)
 
    if (S_ISFIFO (srcmode))
       {
+#ifdef HAVE_MKFIFO
       if (DONTDO)
          {
          printf("cfengine: Make FIFO %s\n",destfile);
@@ -483,6 +484,7 @@ if (lstat(destfile,&deststatbuf) == -1)
 	 Debug2("Leaving ImageCopy\n");
          return;
          }
+#endif
       }
    else
       {
@@ -648,6 +650,9 @@ else
 # endif /* !hpux */
 #endif /* HAVE_ST_BLOCKS */
 
+#ifndef SEEK_CUR
+#define SEEK_CUR 1
+#endif
 
 CopyReg (source,dest,sstat,dstat)
 
