@@ -439,8 +439,9 @@ if (IsWildItemIn(VCOPYLINKS,lastnode) || IsWildItemIn(copy,lastnode))
    ip.exclusions = NULL;
    ip.inclusions = NULL;
    ip.symlink = NULL;
-   ip.classes = NULL;  /* if we get this far don't need to check again */
+   ip.classes = NULL;
    Verbose("cfengine: link item %s marked for copying instead\n",from);
+   MakeDirectoriesFor(to);
    CheckImage(to,from,&ip);
    return;
    }
