@@ -114,7 +114,7 @@ if (!IMAGEBACKUP)
    return true;
    }
 
-if (VREPOSITORY[0] == '\0')
+if (VREPOSITORY[0] == '\0' || HOMECOPY)
    {
    return false;
    }
