@@ -40,7 +40,7 @@ char *str;
   int dollar = false;
   int bracks = 0;
 
-for (sp = str; *sp != NULL ; sp++)       /* check for varitems */
+for (sp = str; *sp != '\0' ; sp++)       /* check for varitems */
    {
    switch (*sp)
       {
@@ -98,18 +98,16 @@ char *string, *buffer, *bserver;
   char currentitem[bufsize], scanstr[6];
   int len;
 
-Debug("ExpandVarstring %s, ",string);
-
 if (bserver != NULL)
    {
-   Debug("(Binserver is %s)\n",bserver);
+   Debug1("(Binserver is %s)\n",bserver);
    }
 
-buffer[0] = NULL;
+buffer[0] = '\0';
 
 for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
    {
-   currentitem[0] = NULL;
+   currentitem[0] = '\0';
 
    sscanf(sp,"%[^$]",currentitem);
 
@@ -133,9 +131,9 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
       sp++;
       }
 
-   currentitem[0] = NULL;
+   currentitem[0] = '\0';
 
-   if (*sp == NULL)
+   if (*sp == '\0')
       {
       break;
       }
@@ -148,7 +146,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
          {
          case fac:
          case sit:
-                   if (VFACULTY[0] == NULL)
+                   if (VFACULTY[0] == '\0')
                       {
                       yyerror("faculty/site undefined variable");
                       }
@@ -184,7 +182,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
                     break;
 
          case sysad:
-                   if (VSYSADM[0] == NULL)
+                   if (VSYSADM[0] == '\0')
                       {
                       yyerror("sysadm undefined variable");
                       }
@@ -197,7 +195,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
                    break;
 
          case dom:
-                   if (VDOMAIN[0] == NULL)
+                   if (VDOMAIN[0] == '\0')
                       {
                       yyerror("domain undefined variable");
                       }
@@ -218,7 +216,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
                    break;
 
          case timez:
-                   if (VTIMEZONE[0] == NULL)
+                   if (VTIMEZONE[0] == '\0')
                       {
                       yyerror("timezone undefined variable");
                       }
@@ -322,7 +320,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
          }
 
       sp += strlen(currentitem);
-      currentitem[0] = NULL;
+      currentitem[0] = '\0';
       }
    }
 
@@ -349,11 +347,11 @@ if (bserver != NULL)
    Debug("(Binserver is %s)\n",bserver);
    }
 
-buffer[0] = NULL;
+buffer[0] = '\0';
 
 for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
    {
-   currentitem[0] = NULL;
+   currentitem[0] = '\0';
 
    sscanf(sp,"%[^$]",currentitem);
 
@@ -377,9 +375,9 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
       sp++;
       }
 
-   currentitem[0] = NULL;
+   currentitem[0] = '\0';
 
-   if (*sp == NULL)
+   if (*sp == '\0')
       {
       break;
       }
@@ -400,7 +398,7 @@ for (sp = string; /* No exit */ ; sp++)       /* check for varitems */
          }
 
       sp += strlen(currentitem);
-      currentitem[0] = NULL;
+      currentitem[0] = '\0';
       }
    }
 
@@ -415,7 +413,7 @@ char *name;
 
 { int i;
 
-for (i = 0; VVNAMES[i] != NULL; i++)
+for (i = 0; VVNAMES[i] != '\0'; i++)
    {
    if (strcmp(VVNAMES[i],name) == 0)
       {
@@ -450,7 +448,7 @@ sprintf(format,"%%[^%c]",sep);   /* set format string to search */
 
 ExpandVarstring(varstring,buffer,""); 
 
-for (sp = buffer; *sp != NULL; sp++)
+for (sp = buffer; *sp != '\0'; sp++)
    {
    bzero(node,maxlinksize);
    sscanf(sp,format,node);
@@ -464,7 +462,7 @@ for (sp = buffer; *sp != NULL; sp++)
 
    AppendItem(&liststart,node,NULL);
 
-   if (*sp == NULL)
+   if (*sp == '\0')
       {
       break;
       }
